translate.lang.mr.mr

Package translate :: Package lang :: Module mr :: Class mr |
[hide private]
[frames] | no frames]

# Class mr

source code

This class represents Marathi.

Instance Methods | [hide private]
Inherited from `common.Common`: `__deepcopy__`, `__repr__` Inherited from `object`: `__delattr__`, `__format__`, `__getattribute__`, `__hash__`, `__init__`, `__reduce__`, `__reduce_ex__`, `__setattr__`, `__sizeof__`, `__str__`, `__subclasshook__`

Class Methods | [hide private]
Inherited from `common.Common`: `alter_length`, `capsstart`, `character_iter`, `characters`, `length_difference`, `punctranslate`, `sentence_iter`, `sentences`, `word_iter`, `words`

Static Methods | [hide private]
Inherited from `common.Common`: `__new__`

Class Variables | [hide private]
| ignoretests = ``[``'``startcaps``'``,` `'``simplecaps``'``]`` List of pofilter tests for this language that must be ignored.
Inherited from `common.Common`: `CJKpunc`, `checker`, `code`, `commonpunc`, `ethiopicpunc`, `fullname`, `indicpunc`, `invertedpunc`, `listseperator`, `miscpunc`, `nplurals`, `pluralequation`, `puncdict`, `punctuation`, `quotes`, `rtlpunc`, `sentenceend`, `sentencere`, `validaccel`, `validdoublewords` Inherited from `common.Common` (private): `_languages`

Properties | [hide private]
Inherited from `object`: `__class__`